@@ -26,7 +26,6 @@ def upload_file(dataset_name, db, settings, client, file_name_with_path, leaf_pa
     ext = file_name.split('.')[-1]
 
     object_name = f'client_{settings.CLIENT_ID}/{relative_file_path}/{uuid.uuid4().hex}.{ext}'
-    logger.info(f'upload file name is {object_name}')
     logger.debug(f'Checking if file needs to be uploaded ...')
 
     # before upload check if file exists on server under this dataset
@@ -49,10 +48,13 @@ def upload_file(dataset_name, db, settings, client, file_name_with_path, leaf_pa
         uploaded_entry = db.get_upload(dataset_name, md5_hash)
 
         if uploaded_entry:
-            logger.debug(f'\tFile with hash {md5_hash} is already uploaded to dataset {dataset_name}.')
+            logger.info(f'File with hash {md5_hash} is already uploaded to dataset {dataset_name}.')
             return uploaded_entry
 
-        logger.info(f'\tUploading to {settings.BUCKET} as {object_name} ...')
+        if not settings.dry:
+            logger.info(f'Uploading {file_name_with_path} to {settings.BUCKET} as {object_name}.')
+        else:
+            logger.info(f'Dry running {file_name_with_path} to {settings.BUCKET} as {object_name}. Nothing will be uploaded.')
         try:
             upload_entry = {
                     'bucket': settings.BUCKET,
@@ -149,7 +151,6 @@ def do_upload(dataset_name, search_path, exclude, settings):
     logger.info(f'Found {num_files} files.')
 
     def single_upload(file_name):
-        logger.info(f'Uploading file {file_name} {settings.BUCKET}')
         db = UploadsDatabase()
         upload_entry = upload_file(dataset_name, db, settings, client, file_name, leaf_path) 
         if not upload_entry:
